# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from instana_client.models.action import Action
from instana_client.models.action_match import ActionMatch
from instana_client.models.action_search_space import ActionSearchSpace
from instana_client.models.get_dynamic_parameter_values import GetDynamicParameterValues
from instana_client.models.tag_catalog import TagCatalog

from instana_client.api_client import ApiClient, RequestSerialized
from instana_client.api_response import ApiResponse
from instana_client.rest import RESTResponseType


class ActionCatalogApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_action_by_id(
        self,
        id: Annotated[StrictStr, Field(description="Automation action ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Action:
        """Get an automation action by ID.

        Get an automation action by ID specified in the request path. When using personal access tokens, the user must have at least `Viewer` access for Automation and the actions returned are also filtered based on the access set in `Limited access` permission settings.

        :param id: Automation action ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Action",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_action_by_id_with_http_info(
        self,
        id: Annotated[StrictStr, Field(description="Automation action ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Action]:
        """Get an automation action by ID.

        Get an automation action by ID specified in the request path. When using personal access tokens, the user must have at least `Viewer` access for Automation and the actions returned are also filtered based on the access set in `Limited access` permission settings.

        :param id: Automation action ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Action",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_action_by_id_without_preload_content(
        self,
        id: Annotated[StrictStr, Field(description="Automation action ID")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get an automation action by ID.

        Get an automation action by ID specified in the request path. When using personal access tokens, the user must have at least `Viewer` access for Automation and the actions returned are also filtered based on the access set in `Limited access` permission settings.

        :param id: Automation action ID (required)
        :type id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_by_id_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Action",
            '403': None,
            '404': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_action_by_id_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/automation/actions/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_action_matches(
        self,
        action_search_space: ActionSearchSpace,
        target_snapshot_id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ActionMatch]:
        """Get automation actions that match the incidents or issues.

        Get automation actions that match the incident or issue data in the request body.

        :param action_search_space: (required)
        :type action_search_space: ActionSearchSpace
        :param target_snapshot_id:
        :type target_snapshot_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_matches_serialize(
            action_search_space=action_search_space,
            target_snapshot_id=target_snapshot_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ActionMatch]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_action_matches_with_http_info(
        self,
        action_search_space: ActionSearchSpace,
        target_snapshot_id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ActionMatch]]:
        """Get automation actions that match the incidents or issues.

        Get automation actions that match the incident or issue data in the request body.

        :param action_search_space: (required)
        :type action_search_space: ActionSearchSpace
        :param target_snapshot_id:
        :type target_snapshot_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_matches_serialize(
            action_search_space=action_search_space,
            target_snapshot_id=target_snapshot_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ActionMatch]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_action_matches_without_preload_content(
        self,
        action_search_space: ActionSearchSpace,
        target_snapshot_id: Optional[StrictStr] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get automation actions that match the incidents or issues.

        Get automation actions that match the incident or issue data in the request body.

        :param action_search_space: (required)
        :type action_search_space: ActionSearchSpace
        :param target_snapshot_id:
        :type target_snapshot_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_matches_serialize(
            action_search_space=action_search_space,
            target_snapshot_id=target_snapshot_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ActionMatch]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_action_matches_serialize(
        self,
        action_search_space,
        target_snapshot_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if target_snapshot_id is not None:
            
            _query_params.append(('targetSnapshotId', target_snapshot_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if action_search_space is not None:
            _body_params = action_search_space


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/automation/ai/action/match',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_action_matches_by_id_and_time_window(
        self,
        application_id: Optional[StrictStr] = None,
        snapshot_id: Optional[StrictStr] = None,
        to: Optional[StrictInt] = None,
        window_size: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[ActionMatch]:
        """Get action matches by application ID or snapshot ID.

        Get automation actions that match based on application ID or snapshot ID within a specified time window.

        :param application_id:
        :type application_id: str
        :param snapshot_id:
        :type snapshot_id: str
        :param to:
        :type to: int
        :param window_size:
        :type window_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_matches_by_id_and_time_window_serialize(
            application_id=application_id,
            snapshot_id=snapshot_id,
            to=to,
            window_size=window_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ActionMatch]",
            '400': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_action_matches_by_id_and_time_window_with_http_info(
        self,
        application_id: Optional[StrictStr] = None,
        snapshot_id: Optional[StrictStr] = None,
        to: Optional[StrictInt] = None,
        window_size: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[ActionMatch]]:
        """Get action matches by application ID or snapshot ID.

        Get automation actions that match based on application ID or snapshot ID within a specified time window.

        :param application_id:
        :type application_id: str
        :param snapshot_id:
        :type snapshot_id: str
        :param to:
        :type to: int
        :param window_size:
        :type window_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_matches_by_id_and_time_window_serialize(
            application_id=application_id,
            snapshot_id=snapshot_id,
            to=to,
            window_size=window_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ActionMatch]",
            '400': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_action_matches_by_id_and_time_window_without_preload_content(
        self,
        application_id: Optional[StrictStr] = None,
        snapshot_id: Optional[StrictStr] = None,
        to: Optional[StrictInt] = None,
        window_size: Optional[StrictInt] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get action matches by application ID or snapshot ID.

        Get automation actions that match based on application ID or snapshot ID within a specified time window.

        :param application_id:
        :type application_id: str
        :param snapshot_id:
        :type snapshot_id: str
        :param to:
        :type to: int
        :param window_size:
        :type window_size: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_action_matches_by_id_and_time_window_serialize(
            application_id=application_id,
            snapshot_id=snapshot_id,
            to=to,
            window_size=window_size,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[ActionMatch]",
            '400': None,
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_action_matches_by_id_and_time_window_serialize(
        self,
        application_id,
        snapshot_id,
        to,
        window_size,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if application_id is not None:
            
            _query_params.append(('applicationId', application_id))
            
        if snapshot_id is not None:
            
            _query_params.append(('snapshotId', snapshot_id))
            
        if to is not None:
            
            _query_params.append(('to', to))
            
        if window_size is not None:
            
            _query_params.append(('windowSize', window_size))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/automation/ai/action/match',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_actions(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[Action]:
        """Get all automation actions.

        Get all automation actions. When using personal access tokens, the user must have at least `Viewer` access for Automation and the actions returned are also filtered based on the access set in `Limited access` permission settings.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_actions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Action]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_actions_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[Action]]:
        """Get all automation actions.

        Get all automation actions. When using personal access tokens, the user must have at least `Viewer` access for Automation and the actions returned are also filtered based on the access set in `Limited access` permission settings.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_actions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Action]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_actions_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all automation actions.

        Get all automation actions. When using personal access tokens, the user must have at least `Viewer` access for Automation and the actions returned are also filtered based on the access set in `Limited access` permission settings.

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_actions_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[Action]",
            '403': None,
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_actions_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/automation/actions',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_dynamic_parameters_tag_catalog(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TagCatalog:
        """Get tag catalog for dynamic parameters


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dynamic_parameters_tag_catalog_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_dynamic_parameters_tag_catalog_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TagCatalog]:
        """Get tag catalog for dynamic parameters


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dynamic_parameters_tag_catalog_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_dynamic_parameters_tag_catalog_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get tag catalog for dynamic parameters


        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_dynamic_parameters_tag_catalog_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TagCatalog",
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_dynamic_parameters_tag_catalog_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/automation/parameters/dynamic/catalog',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def resolve(
        self,
        get_dynamic_parameter_values: GetDynamicParameterValues,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> GetDynamicParameterValues:
        """Resolve dynamic parameter values


        :param get_dynamic_parameter_values: (required)
        :type get_dynamic_parameter_values: GetDynamicParameterValues
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._resolve_serialize(
            get_dynamic_parameter_values=get_dynamic_parameter_values,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetDynamicParameterValues",
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def resolve_with_http_info(
        self,
        get_dynamic_parameter_values: GetDynamicParameterValues,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[GetDynamicParameterValues]:
        """Resolve dynamic parameter values


        :param get_dynamic_parameter_values: (required)
        :type get_dynamic_parameter_values: GetDynamicParameterValues
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._resolve_serialize(
            get_dynamic_parameter_values=get_dynamic_parameter_values,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetDynamicParameterValues",
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def resolve_without_preload_content(
        self,
        get_dynamic_parameter_values: GetDynamicParameterValues,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Resolve dynamic parameter values


        :param get_dynamic_parameter_values: (required)
        :type get_dynamic_parameter_values: GetDynamicParameterValues
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._resolve_serialize(
            get_dynamic_parameter_values=get_dynamic_parameter_values,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "GetDynamicParameterValues",
            '500': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _resolve_serialize(
        self,
        get_dynamic_parameter_values,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if get_dynamic_parameter_values is not None:
            _body_params = get_dynamic_parameter_values


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'ApiKeyAuth'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/automation/parameters/dynamic',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.physical_context import PhysicalContext

class TestPhysicalContext(unittest.TestCase):
    """PhysicalContext unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhysicalContext:
        """Test PhysicalContext
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PhysicalContext`
        """
        model = PhysicalContext()
        if include_optional:
            return PhysicalContext(
                cloudfoundry = instana_client.models.cloudfoundry_physical_context.CloudfoundryPhysicalContext(
                    application = instana_client.models.snapshot_preview.SnapshotPreview(
                        data = {
                            'key' : None
                            }, 
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    cf_instance_index = '', 
                    organization = instana_client.models.snapshot_preview.SnapshotPreview(
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    space = , ),
                cluster = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                container = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                host = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, ),
                kubernetes = instana_client.models.kubernetes_physical_context.KubernetesPhysicalContext(
                    cluster = instana_client.models.snapshot_preview.SnapshotPreview(
                        data = {
                            'key' : None
                            }, 
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    namespace = instana_client.models.snapshot_preview.SnapshotPreview(
                        id = '', 
                        label = '', 
                        plugin = '', 
                        time = 1, ), 
                    node = , 
                    pod = , ),
                process = instana_client.models.snapshot_preview.SnapshotPreview(
                    data = {
                        'key' : None
                        }, 
                    id = '', 
                    label = '', 
                    plugin = '', 
                    time = 1, )
            )
        else:
            return PhysicalContext(
        )
        """

    def testPhysicalContext(self):
        """Test PhysicalContext"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.log_alert_configuration_api import LogAlertConfigurationApi


class TestLogAlertConfigurationApi(unittest.TestCase):
    """LogAlertConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LogAlertConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_create_log_alert_config(self) -> None:
        """Test case for create_log_alert_config

        Create Log Alert Config
        """
        pass

    def test_delete_log_alert_config(self) -> None:
        """Test case for delete_log_alert_config

        Delete Log Alert Config
        """
        pass

    def test_disable_log_alert_config(self) -> None:
        """Test case for disable_log_alert_config

        Disable Log Alert Config
        """
        pass

    def test_enable_log_alert_config(self) -> None:
        """Test case for enable_log_alert_config

        Enable Log Alert Config
        """
        pass

    def test_find_active_log_alert_configs(self) -> None:
        """Test case for find_active_log_alert_configs

        All Log Alert Configs
        """
        pass

    def test_find_log_alert_config(self) -> None:
        """Test case for find_log_alert_config

        Get Log Alert Config
        """
        pass

    def test_find_log_alert_config_versions(self) -> None:
        """Test case for find_log_alert_config_versions

        Get versions of Log Alert Config
        """
        pass

    def test_restore_log_alert_config(self) -> None:
        """Test case for restore_log_alert_config

        Restore Log Alert Config
        """
        pass

    def test_update_log_alert_config(self) -> None:
        """Test case for update_log_alert_config

        Update Log Alert Config
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.trace_item import TraceItem

class TestTraceItem(unittest.TestCase):
    """TraceItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TraceItem:
        """Test TraceItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TraceItem`
        """
        model = TraceItem()
        if include_optional:
            return TraceItem(
                cursor = instana_client.models.cursor.cursor(),
                trace = instana_client.models.trace.Trace(
                    duration = 0, 
                    endpoint = instana_client.models.endpoint.Endpoint(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        is_synthetic = True, 
                        label = '', 
                        service_id = '', 
                        synthetic = True, 
                        synthetic_type = 'NON_SYNTHETIC', 
                        technologies = [
                            ''
                            ], 
                        type = 'UNDEFINED', ), 
                    erroneous = True, 
                    id = '', 
                    label = '', 
                    service = instana_client.models.service.Service(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        label = '', 
                        snapshot_ids = [
                            ''
                            ], 
                        technologies = [
                            ''
                            ], 
                        types = [
                            'UNDEFINED'
                            ], ), 
                    start_time = 1, )
            )
        else:
            return TraceItem(
                cursor = instana_client.models.cursor.cursor(),
                trace = instana_client.models.trace.Trace(
                    duration = 0, 
                    endpoint = instana_client.models.endpoint.Endpoint(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        is_synthetic = True, 
                        label = '', 
                        service_id = '', 
                        synthetic = True, 
                        synthetic_type = 'NON_SYNTHETIC', 
                        technologies = [
                            ''
                            ], 
                        type = 'UNDEFINED', ), 
                    erroneous = True, 
                    id = '', 
                    label = '', 
                    service = instana_client.models.service.Service(
                        entity_type = 'APPLICATION', 
                        id = '', 
                        label = '', 
                        snapshot_ids = [
                            ''
                            ], 
                        technologies = [
                            ''
                            ], 
                        types = [
                            'UNDEFINED'
                            ], ), 
                    start_time = 1, ),
        )
        """

    def testTraceItem(self):
        """Test TraceItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.infrastructure_catalog_api import InfrastructureCatalogApi


class TestInfrastructureCatalogApi(unittest.TestCase):
    """InfrastructureCatalogApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InfrastructureCatalogApi()

    def tearDown(self) -> None:
        pass

    def test_get_available_payload_keys_by_plugin_id(self) -> None:
        """Test case for get_available_payload_keys_by_plugin_id

        Get payload keys for plugin
        """
        pass

    def test_get_infrastructure_catalog_metrics(self) -> None:
        """Test case for get_infrastructure_catalog_metrics

        Get metric catalog
        """
        pass

    def test_get_infrastructure_catalog_plugins(self) -> None:
        """Test case for get_infrastructure_catalog_plugins

        Get plugin catalog
        """
        pass

    def test_get_infrastructure_catalog_plugins_with_custom_metrics(self) -> None:
        """Test case for get_infrastructure_catalog_plugins_with_custom_metrics

        Get all plugins with custom metrics catalog
        """
        pass

    def test_get_infrastructure_catalog_search_fields(self) -> None:
        """Test case for get_infrastructure_catalog_search_fields

        get search field catalog
        """
        pass

    def test_get_tag_catalog(self) -> None:
        """Test case for get_tag_catalog

        Get available tags for a particular plugin
        """
        pass

    def test_get_tag_catalog_all(self) -> None:
        """Test case for get_tag_catalog_all

        Get available tags
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.adjusted_timeframe import AdjustedTimeframe
from instana_client.models.mobile_app_beacons_item import MobileAppBeaconsItem
from typing import Optional, Set
from typing_extensions import Self

class MobileAppBeaconResult(BaseModel):
    """
    MobileAppBeaconResult
    """ # noqa: E501
    adjusted_timeframe: Optional[AdjustedTimeframe] = Field(default=None, alias="adjustedTimeframe")
    can_load_more: Optional[StrictBool] = Field(default=None, description="Determine if additional data is available when a new query is made using the cursor from the last item in the `items` list.", alias="canLoadMore")
    items: List[MobileAppBeaconsItem] = Field(description="Represents an array of call group item containing several attributes that describe its properties. The item includes fields such as cursor, metrics, name, and timestamp, which provide detailed information about the item. ")
    total_hits: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="The total number of items that match a given filter", alias="totalHits")
    total_represented_item_count: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="For calls and EUM beacons, one row can represent multiple real items (batched call, sample multiplicity)", alias="totalRepresentedItemCount")
    total_retained_item_count: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, description="For calls and EUM beacons, only a subset is retained for historic data. Each retained row can represent multiple real items due to batching.", alias="totalRetainedItemCount")
    __properties: ClassVar[List[str]] = ["adjustedTimeframe", "canLoadMore", "items", "totalHits", "totalRepresentedItemCount", "totalRetainedItemCount"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MobileAppBeaconResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of adjusted_timeframe
        if self.adjusted_timeframe:
            _dict['adjustedTimeframe'] = self.adjusted_timeframe.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in items (list)
        _items = []
        if self.items:
            for _item_items in self.items:
                if _item_items:
                    _items.append(_item_items.to_dict())
            _dict['items'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MobileAppBeaconResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "adjustedTimeframe": AdjustedTimeframe.from_dict(obj["adjustedTimeframe"]) if obj.get("adjustedTimeframe") is not None else None,
            "canLoadMore": obj.get("canLoadMore"),
            "items": [MobileAppBeaconsItem.from_dict(_item) for _item in obj["items"]] if obj.get("items") is not None else None,
            "totalHits": obj.get("totalHits"),
            "totalRepresentedItemCount": obj.get("totalRepresentedItemCount"),
            "totalRetainedItemCount": obj.get("totalRetainedItemCount")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.maintenance_config_scheduling import MaintenanceConfigScheduling
from instana_client.models.occurrence import Occurrence
from instana_client.models.tag_filter_expression_element import TagFilterExpressionElement
from typing import Optional, Set
from typing_extensions import Self

class MaintenanceConfigV2WithStateAndOccurrence(BaseModel):
    """
    MaintenanceConfigV2WithStateAndOccurrence
    """ # noqa: E501
    id: Annotated[str, Field(min_length=0, strict=True, max_length=64)] = Field(description="ID of the Maintenance Window configuration.")
    last_updated: Optional[Annotated[int, Field(strict=True, ge=1)]] = Field(default=None, alias="lastUpdated")
    name: Annotated[str, Field(min_length=0, strict=True, max_length=256)] = Field(description="Name of the Maintenance Window configuration.")
    occurrence: Occurrence
    paused: Optional[StrictBool] = Field(default=None, description="Boolean flag to determine if the Maintenance Window configuration is paused or still live.")
    query: Annotated[str, Field(min_length=0, strict=True, max_length=2048)] = Field(description="Dynamic Focus Query that determines the scope of the Maintenance Window configuration.")
    retrigger_open_alerts_enabled: Optional[StrictBool] = Field(default=None, description="Boolean flag to determine if we should retrigger open alerts to be sent out for any events that opened during this maintenance window, and continues to remain open after the window expires", alias="retriggerOpenAlertsEnabled")
    scheduling: MaintenanceConfigScheduling
    state: Optional[StrictStr] = Field(default=None, description="State of the Maintenance Window, it can be: UNSCHEDULED, SCHEDULED, ACTIVE, PAUSED, EXPIRED.")
    tag_filter_expression: Optional[TagFilterExpressionElement] = Field(default=None, alias="tagFilterExpression")
    tag_filter_expression_enabled: Optional[StrictBool] = Field(default=None, description="Boolean flag to determine if the tagFilterExpression is enabled.", alias="tagFilterExpressionEnabled")
    __properties: ClassVar[List[str]] = ["id", "lastUpdated", "name", "occurrence", "paused", "query", "retriggerOpenAlertsEnabled", "scheduling", "state", "tagFilterExpression", "tagFilterExpressionEnabled"]

    @field_validator('state')
    def state_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['UNSCHEDULED', 'SCHEDULED', 'ACTIVE', 'PAUSED', 'EXPIRED']):
            raise ValueError("must be one of enum values ('UNSCHEDULED', 'SCHEDULED', 'ACTIVE', 'PAUSED', 'EXPIRED')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MaintenanceConfigV2WithStateAndOccurrence from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of occurrence
        if self.occurrence:
            _dict['occurrence'] = self.occurrence.to_dict()
        # override the default output from pydantic by calling `to_dict()` of scheduling
        if self.scheduling:
            _dict['scheduling'] = self.scheduling.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tag_filter_expression
        if self.tag_filter_expression:
            _dict['tagFilterExpression'] = self.tag_filter_expression.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MaintenanceConfigV2WithStateAndOccurrence from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "lastUpdated": obj.get("lastUpdated"),
            "name": obj.get("name"),
            "occurrence": Occurrence.from_dict(obj["occurrence"]) if obj.get("occurrence") is not None else None,
            "paused": obj.get("paused"),
            "query": obj.get("query"),
            "retriggerOpenAlertsEnabled": obj.get("retriggerOpenAlertsEnabled"),
            "scheduling": MaintenanceConfigScheduling.from_dict(obj["scheduling"]) if obj.get("scheduling") is not None else None,
            "state": obj.get("state"),
            "tagFilterExpression": TagFilterExpressionElement.from_dict(obj["tagFilterExpression"]) if obj.get("tagFilterExpression") is not None else None,
            "tagFilterExpressionEnabled": obj.get("tagFilterExpressionEnabled")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.synthetic_geo_point import SyntheticGeoPoint
from instana_client.models.synthetic_location_configuration import SyntheticLocationConfiguration
from instana_client.models.synthetic_playback_capabilities import SyntheticPlaybackCapabilities
from typing import Optional, Set
from typing_extensions import Self

class SyntheticLocation(BaseModel):
    """
    SyntheticLocation
    """ # noqa: E501
    configuration: Optional[SyntheticLocationConfiguration] = None
    created_at: Optional[StrictInt] = Field(default=None, alias="createdAt")
    custom_properties: Optional[Dict[str, StrictStr]] = Field(default=None, alias="customProperties")
    description: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=512)]] = None
    display_label: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=128)]] = Field(default=None, alias="displayLabel")
    geo_point: SyntheticGeoPoint = Field(alias="geoPoint")
    id: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=128)]] = None
    label: Annotated[str, Field(min_length=1, strict=True, max_length=128)]
    location_type: StrictStr = Field(alias="locationType")
    modified_at: Optional[StrictInt] = Field(default=None, alias="modifiedAt")
    observed_at: Optional[StrictInt] = Field(default=None, alias="observedAt")
    playback_capabilities: SyntheticPlaybackCapabilities = Field(alias="playbackCapabilities")
    pop_version: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=64)]] = Field(default=None, alias="popVersion")
    status: Optional[StrictStr] = None
    total_tests: Optional[StrictInt] = Field(default=None, alias="totalTests")
    __properties: ClassVar[List[str]] = ["configuration", "createdAt", "customProperties", "description", "displayLabel", "geoPoint", "id", "label", "locationType", "modifiedAt", "observedAt", "playbackCapabilities", "popVersion", "status", "totalTests"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SyntheticLocation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of configuration
        if self.configuration:
            _dict['configuration'] = self.configuration.to_dict()
        # override the default output from pydantic by calling `to_dict()` of geo_point
        if self.geo_point:
            _dict['geoPoint'] = self.geo_point.to_dict()
        # override the default output from pydantic by calling `to_dict()` of playback_capabilities
        if self.playback_capabilities:
            _dict['playbackCapabilities'] = self.playback_capabilities.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SyntheticLocation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "configuration": SyntheticLocationConfiguration.from_dict(obj["configuration"]) if obj.get("configuration") is not None else None,
            "createdAt": obj.get("createdAt"),
            "customProperties": obj.get("customProperties"),
            "description": obj.get("description"),
            "displayLabel": obj.get("displayLabel"),
            "geoPoint": SyntheticGeoPoint.from_dict(obj["geoPoint"]) if obj.get("geoPoint") is not None else None,
            "id": obj.get("id"),
            "label": obj.get("label"),
            "locationType": obj.get("locationType"),
            "modifiedAt": obj.get("modifiedAt"),
            "observedAt": obj.get("observedAt"),
            "playbackCapabilities": SyntheticPlaybackCapabilities.from_dict(obj["playbackCapabilities"]) if obj.get("playbackCapabilities") is not None else None,
            "popVersion": obj.get("popVersion"),
            "status": obj.get("status"),
            "totalTests": obj.get("totalTests")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.test_common_properties import TestCommonProperties

class TestTestCommonProperties(unittest.TestCase):
    """TestCommonProperties unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestCommonProperties:
        """Test TestCommonProperties
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestCommonProperties`
        """
        model = TestCommonProperties()
        if include_optional:
            return TestCommonProperties(
                active = True,
                application_id = '',
                application_ids = [
                    ''
                    ],
                application_label = '',
                application_labels = [
                    ''
                    ],
                created_at = 56,
                frequency = 56,
                get_website_labels = [
                    ''
                    ],
                id = '',
                label = '',
                location_display_labels = [
                    ''
                    ],
                location_ids = [
                    ''
                    ],
                location_labels = [
                    ''
                    ],
                location_status_list = [
                    instana_client.models.location_status.LocationStatus(
                        location_display_label = '', 
                        location_id = '', 
                        success_rate = 1.337, 
                        success_runs = 56, 
                        total_test_runs = 56, )
                    ],
                mobile_application_ids = [
                    ''
                    ],
                mobile_application_labels = [
                    ''
                    ],
                modified_at = 56,
                service_id = '',
                type = '',
                website_ids = [
                    ''
                    ],
                website_labels = [
                    ''
                    ]
            )
        else:
            return TestCommonProperties(
                active = True,
                frequency = 56,
                id = '',
                label = '',
                type = '',
        )
        """

    def testTestCommonProperties(self):
        """Test TestCommonProperties"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.models.website_beacons_item import WebsiteBeaconsItem

class TestWebsiteBeaconsItem(unittest.TestCase):
    """WebsiteBeaconsItem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WebsiteBeaconsItem:
        """Test WebsiteBeaconsItem
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WebsiteBeaconsItem`
        """
        model = WebsiteBeaconsItem()
        if include_optional:
            return WebsiteBeaconsItem(
                beacon = instana_client.models.website_monitoring_beacon.WebsiteMonitoringBeacon(
                    accuracy_radius = -1, 
                    accurate_timings_available = True, 
                    agent_version = '', 
                    app_cache_time = -1, 
                    backend_time = -1, 
                    backend_trace_id = '', 
                    batch_size = 1, 
                    beacon_id = '', 
                    browser_name = '', 
                    browser_version = '', 
                    bytes_ingested = 56, 
                    cache_interaction = '', 
                    children_time = -1, 
                    city = '', 
                    clock_skew = -1, 
                    component_stack = '', 
                    connection_type = '', 
                    continent = '', 
                    continent_code = '', 
                    country = '', 
                    country_code = '', 
                    csp_blocked_uri = '', 
                    csp_column_number = 56, 
                    csp_disposition = '', 
                    csp_effective_directive = '', 
                    csp_line_number = 56, 
                    csp_original_policy = '', 
                    csp_sample = '', 
                    csp_source_file = '', 
                    cumulative_layout_shift = 1.337, 
                    custom_event_name = '', 
                    custom_metric = 1.337, 
                    decoded_body_size = -1, 
                    deprecations = [
                        ''
                        ], 
                    device_type = '', 
                    dns_time = -1, 
                    dom_time = -1, 
                    duration = 0, 
                    encoded_body_size = -1, 
                    error_count = 0, 
                    error_id = '', 
                    error_message = '', 
                    error_type = '', 
                    first_contentful_paint_time = -1, 
                    first_input_delay_time = -1, 
                    first_paint_time = -1, 
                    frontend_time = -1, 
                    graphql_operation_name = '', 
                    graphql_operation_type = '', 
                    http_call_asynchronous = True, 
                    http_call_correlation_attempted = True, 
                    http_call_headers = {
                        'key' : ''
                        }, 
                    http_call_method = '', 
                    http_call_origin = '', 
                    http_call_path = '', 
                    http_call_status = -1, 
                    http_call_url = '', 
                    initiator = '', 
                    interaction_next_paint = 56, 
                    internal_meta = {
                        'key' : ''
                        }, 
                    label = '', 
                    largest_contentful_paint_time = -1, 
                    latitude = 1.337, 
                    location_origin = '', 
                    location_path = '', 
                    location_url = '', 
                    longitude = 1.337, 
                    meta = {
                        'key' : ''
                        }, 
                    on_load_time = -1, 
                    os_name = '', 
                    os_version = '', 
                    page = '', 
                    page_load_id = '', 
                    parent_beacon_id = '', 
                    parsed_stack_trace = [
                        instana_client.models.js_stack_trace_line.JsStackTraceLine(
                            column = -1, 
                            file = '', 
                            line = -1, 
                            name = '', 
                            translation_explanation = '', 
                            translation_status = -1, )
                        ], 
                    phase = '', 
                    processing_time = -1, 
                    redirect_time = -1, 
                    request_time = -1, 
                    resource_type = '', 
                    response_time = -1, 
                    session_id = '', 
                    snippet_version = '', 
                    ssl_time = -1, 
                    stack_trace = '', 
                    stack_trace_parsing_status = -1, 
                    stack_trace_readability = 0, 
                    subdivision = '', 
                    subdivision_code = '', 
                    tcp_time = -1, 
                    timestamp = 1, 
                    transfer_size = -1, 
                    type = '', 
                    unload_time = -1, 
                    use_features = [
                        ''
                        ], 
                    user_email = '', 
                    user_id = '', 
                    user_ip = '', 
                    user_languages = [
                        ''
                        ], 
                    user_name = '', 
                    website_id = '', 
                    website_label = '', 
                    window_height = -1, 
                    window_hidden = True, 
                    window_width = -1, ),
                cursor = instana_client.models.cursor.cursor(),
                impacted_beacon_info = instana_client.models.impacted_beacon_info.ImpactedBeaconInfo(
                    country = '', 
                    label = '', 
                    subdivision = '', 
                    user_email = '', 
                    user_name = '', )
            )
        else:
            return WebsiteBeaconsItem(
                beacon = instana_client.models.website_monitoring_beacon.WebsiteMonitoringBeacon(
                    accuracy_radius = -1, 
                    accurate_timings_available = True, 
                    agent_version = '', 
                    app_cache_time = -1, 
                    backend_time = -1, 
                    backend_trace_id = '', 
                    batch_size = 1, 
                    beacon_id = '', 
                    browser_name = '', 
                    browser_version = '', 
                    bytes_ingested = 56, 
                    cache_interaction = '', 
                    children_time = -1, 
                    city = '', 
                    clock_skew = -1, 
                    component_stack = '', 
                    connection_type = '', 
                    continent = '', 
                    continent_code = '', 
                    country = '', 
                    country_code = '', 
                    csp_blocked_uri = '', 
                    csp_column_number = 56, 
                    csp_disposition = '', 
                    csp_effective_directive = '', 
                    csp_line_number = 56, 
                    csp_original_policy = '', 
                    csp_sample = '', 
                    csp_source_file = '', 
                    cumulative_layout_shift = 1.337, 
                    custom_event_name = '', 
                    custom_metric = 1.337, 
                    decoded_body_size = -1, 
                    deprecations = [
                        ''
                        ], 
                    device_type = '', 
                    dns_time = -1, 
                    dom_time = -1, 
                    duration = 0, 
                    encoded_body_size = -1, 
                    error_count = 0, 
                    error_id = '', 
                    error_message = '', 
                    error_type = '', 
                    first_contentful_paint_time = -1, 
                    first_input_delay_time = -1, 
                    first_paint_time = -1, 
                    frontend_time = -1, 
                    graphql_operation_name = '', 
                    graphql_operation_type = '', 
                    http_call_asynchronous = True, 
                    http_call_correlation_attempted = True, 
                    http_call_headers = {
                        'key' : ''
                        }, 
                    http_call_method = '', 
                    http_call_origin = '', 
                    http_call_path = '', 
                    http_call_status = -1, 
                    http_call_url = '', 
                    initiator = '', 
                    interaction_next_paint = 56, 
                    internal_meta = {
                        'key' : ''
                        }, 
                    label = '', 
                    largest_contentful_paint_time = -1, 
                    latitude = 1.337, 
                    location_origin = '', 
                    location_path = '', 
                    location_url = '', 
                    longitude = 1.337, 
                    meta = {
                        'key' : ''
                        }, 
                    on_load_time = -1, 
                    os_name = '', 
                    os_version = '', 
                    page = '', 
                    page_load_id = '', 
                    parent_beacon_id = '', 
                    parsed_stack_trace = [
                        instana_client.models.js_stack_trace_line.JsStackTraceLine(
                            column = -1, 
                            file = '', 
                            line = -1, 
                            name = '', 
                            translation_explanation = '', 
                            translation_status = -1, )
                        ], 
                    phase = '', 
                    processing_time = -1, 
                    redirect_time = -1, 
                    request_time = -1, 
                    resource_type = '', 
                    response_time = -1, 
                    session_id = '', 
                    snippet_version = '', 
                    ssl_time = -1, 
                    stack_trace = '', 
                    stack_trace_parsing_status = -1, 
                    stack_trace_readability = 0, 
                    subdivision = '', 
                    subdivision_code = '', 
                    tcp_time = -1, 
                    timestamp = 1, 
                    transfer_size = -1, 
                    type = '', 
                    unload_time = -1, 
                    use_features = [
                        ''
                        ], 
                    user_email = '', 
                    user_id = '', 
                    user_ip = '', 
                    user_languages = [
                        ''
                        ], 
                    user_name = '', 
                    website_id = '', 
                    website_label = '', 
                    window_height = -1, 
                    window_hidden = True, 
                    window_width = -1, ),
                cursor = instana_client.models.cursor.cursor(),
        )
        """

    def testWebsiteBeaconsItem(self):
        """Test WebsiteBeaconsItem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MetricDescription(BaseModel):
    """
    MetricDescription
    """ # noqa: E501
    aggregations: List[StrictStr] = Field(description="The types of aggregations that can be applied to a series of values. For example, `P25` is 25th percentile. Note that not all aggregations are available for metrics. For example, `Trace count` has only `SUM` as an aggregation whereas `Call Count` has two aggregations, `SUM` and `PER_SECOND`. ")
    default_aggregation: Optional[StrictStr] = Field(default=None, description="The preselected aggregation for a metric. For example, for `Call latency` the default aggregation is `MEAN`.", alias="defaultAggregation")
    description: Optional[StrictStr] = Field(default=None, description="A description of the metric. For example, for `Call count` metric, the description would be something like `Number of received calls`")
    formatter: StrictStr = Field(description="* `NUMBER`: Generic number * `BYTES`: Number of bytes * `KILO_BYTES`: Number of kilobytes * `MEGA_BYTES`: Number of megabytes * `PERCENTAGE`: Percentage in scale [0,1] * `PERCENTAGE_100`: Percentage in scale [0,100] * `PERCENTAGE_NO_CAPPING`: Percentage in scale [0,1] but value could exceed 1 for example when metric is aggregated * `PERCENTAGE_100_NO_CAPPING`: Percentage in scale [0,100] but value could exceed 100 for example when metric is aggregated * `LATENCY`: Time in milliseconds, with value of 0 should not be considered a a strict 0, but considered as < 1ms * `NANOS`: Time in nanoseconds * `MILLIS`: Time in milliseconds * `MICROS`: Time in microseconds * `SECONDS`: Time in seconds * `RATE`: Number of occurrences per second * `BYTE_RATE`: Number of bytes per second * `UNDEFINED`: Metric value unit is not known ")
    label: StrictStr = Field(description="The name of the metric. For example, `Call count`, `Erroneous calls`, `Service count` etc.")
    metric_id: StrictStr = Field(description="The unique id of the metric. For example, `calls`, `erroneousCalls`, `latency` etc.", alias="metricId")
    __properties: ClassVar[List[str]] = ["aggregations", "defaultAggregation", "description", "formatter", "label", "metricId"]

    @field_validator('aggregations')
    def aggregations_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(['SUM', 'MEAN', 'MAX', 'MIN', 'P25', 'P50', 'P75', 'P90', 'P95', 'P98', 'P99', 'P99_9', 'P99_99', 'DISTINCT_COUNT', 'SUM_POSITIVE', 'PER_SECOND', 'INCREASE']):
                raise ValueError("each list item must be one of ('SUM', 'MEAN', 'MAX', 'MIN', 'P25', 'P50', 'P75', 'P90', 'P95', 'P98', 'P99', 'P99_9', 'P99_99', 'DISTINCT_COUNT', 'SUM_POSITIVE', 'PER_SECOND', 'INCREASE')")
        return value

    @field_validator('default_aggregation')
    def default_aggregation_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SUM', 'MEAN', 'MAX', 'MIN', 'P25', 'P50', 'P75', 'P90', 'P95', 'P98', 'P99', 'P99_9', 'P99_99', 'DISTINCT_COUNT', 'SUM_POSITIVE', 'PER_SECOND', 'INCREASE']):
            raise ValueError("must be one of enum values ('SUM', 'MEAN', 'MAX', 'MIN', 'P25', 'P50', 'P75', 'P90', 'P95', 'P98', 'P99', 'P99_9', 'P99_99', 'DISTINCT_COUNT', 'SUM_POSITIVE', 'PER_SECOND', 'INCREASE')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetricDescription from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetricDescription from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aggregations": obj.get("aggregations"),
            "defaultAggregation": obj.get("defaultAggregation"),
            "description": obj.get("description"),
            "formatter": obj.get("formatter"),
            "label": obj.get("label"),
            "metricId": obj.get("metricId")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class Parameter(BaseModel):
    """
    List of inputs to the action.
    """ # noqa: E501
    description: Optional[StrictStr] = Field(default=None, description="Parameter description.")
    hidden: Optional[StrictBool] = Field(default=None, description="Is parameter hidden or not.")
    label: StrictStr = Field(description="Parameter label.")
    name: StrictStr = Field(description="Parameter name.")
    required: Optional[StrictBool] = Field(default=None, description="Is parameter required or not.")
    secured: Optional[StrictBool] = Field(default=None, description="Is parameter secured or not.")
    type: StrictStr = Field(description="Parameter type. Valid values are `static`, `dynamic`, or `vault`. Default value is `static`")
    value: Optional[StrictStr] = Field(default=None, description="Parameter value.")
    __properties: ClassVar[List[str]] = ["description", "hidden", "label", "name", "required", "secured", "type", "value"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Parameter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Parameter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "hidden": obj.get("hidden"),
            "label": obj.get("label"),
            "name": obj.get("name"),
            "required": obj.get("required"),
            "secured": obj.get("secured"),
            "type": obj.get("type"),
            "value": obj.get("value")
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from instana_client.models.ssl_certificate_validation import SSLCertificateValidation
from instana_client.models.synthetic_type_configuration import SyntheticTypeConfiguration
from typing import Optional, Set
from typing_extensions import Self

class SSLCertificateConfiguration(SyntheticTypeConfiguration):
    """
    SSLCertificateConfiguration
    """ # noqa: E501
    accept_self_signed_certificate: Optional[StrictBool] = Field(default=None, alias="acceptSelfSignedCertificate")
    days_remaining_check: Annotated[int, Field(le=365, strict=True, ge=1)] = Field(alias="daysRemainingCheck")
    hostname: Annotated[str, Field(min_length=0, strict=True, max_length=2047)]
    port: Optional[StrictInt] = None
    validation_rules: Optional[List[SSLCertificateValidation]] = Field(default=None, alias="validationRules")
    __properties: ClassVar[List[str]] = ["markSyntheticCall", "retries", "retryInterval", "syntheticType", "timeout", "acceptSelfSignedCertificate", "daysRemainingCheck", "hostname", "port", "validationRules"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SSLCertificateConfiguration from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in validation_rules (list)
        _items = []
        if self.validation_rules:
            for _item_validation_rules in self.validation_rules:
                if _item_validation_rules:
                    _items.append(_item_validation_rules.to_dict())
            _dict['validationRules'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SSLCertificateConfiguration from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "markSyntheticCall": obj.get("markSyntheticCall"),
            "retries": obj.get("retries"),
            "retryInterval": obj.get("retryInterval"),
            "syntheticType": obj.get("syntheticType"),
            "timeout": obj.get("timeout"),
            "acceptSelfSignedCertificate": obj.get("acceptSelfSignedCertificate"),
            "daysRemainingCheck": obj.get("daysRemainingCheck"),
            "hostname": obj.get("hostname"),
            "port": obj.get("port"),
            "validationRules": [SSLCertificateValidation.from_dict(_item) for _item in obj["validationRules"]] if obj.get("validationRules") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.306.1368
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from instana_client.api.host_agent_api import HostAgentApi


class TestHostAgentApi(unittest.TestCase):
    """HostAgentApi unit test stubs"""

    def setUp(self) -> None:
        self.api = HostAgentApi()

    def tearDown(self) -> None:
        pass

    def test_get_agent_clr_logs(self) -> None:
        """Test case for get_agent_clr_logs

        Agent CLR download logs
        """
        pass

    def test_get_agent_logs(self) -> None:
        """Test case for get_agent_logs

        Agent download logs
        """
        pass

    def test_get_agent_snapshot(self) -> None:
        """Test case for get_agent_snapshot

        Get host agent snapshot details
        """
        pass

    def test_get_agent_support_information(self) -> None:
        """Test case for get_agent_support_information

        Agent download support information
        """
        pass

    def test_search_host_agents(self) -> None:
        """Test case for search_host_agents

        Query host agent snapshots
        """
        pass

    def test_update_agent(self) -> None:
        """Test case for update_agent

        Agent update
        """
        pass

    def test_update_configuration_by_host(self) -> None:
        """Test case for update_configuration_by_host

        Update agent configuration by host
        """
        pass

    def test_update_configuration_by_query(self) -> None:
        """Test case for update_configuration_by_query

        Update agent configuration by query
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Instana REST API documentation

    Documentation for INSTANA REST API

    The version of the OpenAPI document: 1.309.1268
    Contact: support@instana.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class ExtendedService(BaseModel):
    """
    List of services in the topology.
    """ # noqa: E501
    applications: List[StrictStr]
    entity_type: Optional[StrictStr] = Field(default=None, description="Since, this is a Service, it will be of type `SERVICE`.", alias="entityType")
    id: StrictStr = Field(description="Unique ID of the Service. Eg: `3feb3dcd206c166ef2b41c707e0cd38d7cd325aa`.")
    label: StrictStr = Field(description="Name of the Service. Eg: `payment`.")
    max_severity: Optional[Union[Annotated[float, Field(le=10, strict=True, ge=0)], Annotated[int, Field(le=10, strict=True, ge=0)]]] = Field(default=None, alias="maxSeverity")
    number_of_open_issues: Optional[Annotated[int, Field(strict=True, ge=0)]] = Field(default=None, alias="numberOfOpenIssues")
    snapshot_ids: List[StrictStr] = Field(description="A unique identifier the metrics are assigned to.", alias="snapshotIds")
    technologies: List[StrictStr] = Field(description="List of technologies: `Eg:[\"springbootApplicationContainer\"]`")
    types: List[StrictStr] = Field(description="Shows types of Endpoints a Service can consist of. It may be one or more. Eg: `HTTP` `OPENTELEMETRY` can be in 1 Service.")
    __properties: ClassVar[List[str]] = ["applications", "entityType", "id", "label", "maxSeverity", "numberOfOpenIssues", "snapshotIds", "technologies", "types"]

    @field_validator('entity_type')
    def entity_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['APPLICATION', 'SERVICE', 'ENDPOINT']):
            raise ValueError("must be one of enum values ('APPLICATION', 'SERVICE', 'ENDPOINT')")
        return value

    @field_validator('types')
    def types_validate_enum(cls, value):
        """Validates the enum"""
        for i in value:
            if i not in set(['UNDEFINED', 'RPC', 'EVENT', 'GRAPHQL', 'BATCH', 'SHELL', 'HTTP', 'SDK', 'OPENTELEMETRY', 'INTERNAL', 'DATABASE', 'MESSAGING', 'PAGE', 'PAGE_RESOURCE']):
                raise ValueError("each list item must be one of ('UNDEFINED', 'RPC', 'EVENT', 'GRAPHQL', 'BATCH', 'SHELL', 'HTTP', 'SDK', 'OPENTELEMETRY', 'INTERNAL', 'DATABASE', 'MESSAGING', 'PAGE', 'PAGE_RESOURCE')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ExtendedService from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ExtendedService from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "applications": obj.get("applications"),
            "entityType": obj.get("entityType"),
            "id": obj.get("id"),
            "label": obj.get("label"),
            "maxSeverity": obj.get("maxSeverity"),
            "numberOfOpenIssues": obj.get("numberOfOpenIssues"),
            "snapshotIds": obj.get("snapshotIds"),
            "technologies": obj.get("technologies"),
            "types": obj.get("types")
        })
        return _obj


